from elibs.tom_ticket.api import TomTicket
from elibs.utils import join_path, get_ip, check_path, dict_to_prop
from elibs.ui import MainApp, MainWindow, ICON

__all__ = ['TomTicket', 'dict_to_prop', 'check_path', 'get_ip', 'join_path', 'MainApp', 'MainWindow', 'ICON']



from wx import *

ICON = None


class MainApp(App):
    def __init__(self, *args, **kwargs):
        super(MainApp, self).__init__(args, kwargs)


class MainWindow(Frame):
    def __init__(self, parent):
        super(MainWindow, self).__init__(parent)
        self.SetIcon(ICON)
